const { h, Component } = require('preact')
const shortid = require('shortid')

/**
 * A checkbox input, compatible with "withValidation" hoc.
 * @prop {String} name - name attribute
 * @prop {String} label - label text (html allowed)
 * @prop {Boolean} value - initial value
 * @prop {Boolean} on_dark - adjust css for dark backgrounds
 * @prop {Function} onValueChange - function called with the value when it
 * changes
 */
export default class BooleanInput extends Component {
  constructor(props) {
    super(props)
    this.state = { value: props.value || false }
    this.shortid = shortid.generate()
  }
  componentDidUpdate(prevProps, prevState) {
    // when the value changes, validate and reflect to parent if applicable
    if (this.state.value !== prevState.value) {
      this.props.onValueChange && this.props.onValueChange(this.state.value)
    }

    // if a parent changes the value, reflect it to the state
    if (this.props.value !== prevProps.value) {
      this.setState({ value: this.props.value })
    }
  }
  render() {
    const classes = ['g-boolean-input']
    if (this.props.on_dark) {
      classes.push('on-dark')
    }
    return (
      <div class={classes.join(' ')}>
        <input
          type="checkbox"
          name={this.props.name}
          id={`id-${this.props.name}-${this.shortid}`}
          ref={el => (this.inputEl = el)}
          value={this.state.value}
          onChange={e => this.setState({ value: e.target.checked })}
        />
        <label htmlFor={`id-${this.props.name}-${this.shortid}`}>
          <span dangerouslySetInnerHTML={{ __html: this.props.label }} />
        </label>
      </div>
    )
  }
}
